==> mongodb-5.0.31.gh.tar.gz: mongo-r5.0.31/src/mongo/base/counter_test.cpp <==
/**
 *    Copyright (C) 2018-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */


#include "mongo/platform/basic.h"

#include <climits>
#include <iostream>

#include "mongo/base/counter.h"
#include "mongo/unittest/unittest.h"

namespace mongo {
namespace {
TEST(CounterTest, Test1) {
    Counter64 c;
    ASSERT_EQUALS(c.get(), 0);
    c.increment();
    ASSERT_EQUALS(c.get(), 1);
    c.decrement();
    ASSERT_EQUALS(c.get(), 0);
    c.decrement(3);
    ASSERT_EQUALS(c.get(), -3);
    c.increment(1);
    ASSERT_EQUALS(c.get(), -2);
    c.decrement(-1);
    ASSERT_EQUALS(c.get(), -1);
    c.increment();
    ASSERT_EQUALS(static_cast<long long>(c), 0);
}

}  // namespace
}  // namespace mongo

==> mongodb-8.0.12.gh.tar.gz: mongo-r8.0.12/src/mongo/base/counter_test.cpp <==
/**
 *    Copyright (C) 2018-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */


#include "mongo/base/counter.h"
#include "mongo/base/string_data.h"
#include "mongo/unittest/assert.h"
#include "mongo/unittest/framework.h"

namespace mongo {
namespace {
TEST(CounterTest, IncrementDecrement) {
    Counter64 c;
    ASSERT_EQUALS(c.get(), 0);
    c.increment();
    ASSERT_EQUALS(c.get(), 1);
    c.decrement();
    ASSERT_EQUALS(c.get(), 0);
    c.decrement(3);
    ASSERT_EQUALS(c.get(), -3);
    c.increment(1);
    ASSERT_EQUALS(c.get(), -2);
    c.decrement(-1);
    ASSERT_EQUALS(c.get(), -1);
}

TEST(CounterTest, IncrementDecrementRelaxed) {
    Counter64 c;
    ASSERT_EQUALS(c.get(), 0);
    c.incrementRelaxed();
    ASSERT_EQUALS(c.get(), 1);
    c.decrementRelaxed();
    ASSERT_EQUALS(c.get(), 0);
    c.decrementRelaxed(3);
    ASSERT_EQUALS(c.get(), -3);
    c.incrementRelaxed(1);
    ASSERT_EQUALS(c.get(), -2);
    c.decrementRelaxed(-1);
    ASSERT_EQUALS(c.get(), -1);
}

}  // namespace
}  // namespace mongo
